// Copyright 2016 Tadd Torborg -- I grant the right to modify and sell products using this sourcecode.  
//I insist you put my copyright notice and this line in every sourcecode file included in any project which uses my PWRMAN software. 
// If you do manage to construct or produce 2 or more devices based on this source code, please send an email to me at tadd@mac.com
//  Thanks!! 
// Source code by Tadd Torborg, ham-radio callsign KA2DEW, for PWRMAN power controller -- runs on TI MSP430F2012 CPU.
// Concept by Tadd Torborg.  Board design, layout, stuffed, and maintained by Stephen Snell, ham-radio callsign W4RFQ
// PWRMAN operation is documented on the TARPN web site.  See  http://tarpn.net/pwrman
// I compiled and debugged this project using IAR's EW430 version 5.
//

//This file was not compiled in the released product because I ran out of code space.


//IAR or TI includes
#include "string.h"
#include "stdlib.h"
#include "io430.h"
#include "intrinsics.h"

//PWRMAN includes
#include "common.h"
#include "pwrman.h"
#include "testmode.h"
#include "sw_led.h"

//#define NOTEST

#ifdef NOTEST
void TestMode()
{
}
#else

static void BlinkBlueLedOnceIfButtonNotPressed(void);




///########################################################################################
// LONG DELAY IF NO BUTTON PRESS
//
//
static void LongDelayIfNoButtonPress(unsigned short passed_delayLength)
{
   unsigned short x_l;                                         // WDTCTL is declared volatile, so x does not need to be volatile too.
   for(x_l = 0; x_l < passed_delayLength; x_l++)
   {
      if(ReadPushButtons() == NOTHING_PUSHED) ShortDelay(1000);                                  // reset watchdog timer
   }
}
///########################################################################################

static void WaitForButtonUp(void)
{
   while(ReadPushButtons() != NOTHING_PUSHED)
   { }
}

#define ONELED_RED 1
#define ONELED_BLUE 2
#define ONELED_GREEN 3
#define NO_LED 0
static void WriteOneLedOn(unsigned short passed_ledNum)
{
   WriteAllLeds(OFF, OFF, OFF);
   switch(passed_ledNum)
   {
      case ONELED_RED:
         WriteRedLED(ON);
         break;

      case ONELED_BLUE:
         WriteBlueLED(ON);
         break;

      case ONELED_GREEN:
         WriteGreenLED(ON);
         break;

      default:
         break;
   }
}

static void BlinkBlueLedOnceIfButtonNotPressed(void)
{
   WriteBlueLED(ON);
   if(ReadPushButtons() == NOTHING_PUSHED)
   {
      LongDelayIfNoButtonPress(10);
   }
   WriteBlueLED(OFF);
   if(ReadPushButtons() == NOTHING_PUSHED)
   {
      LongDelayIfNoButtonPress(20);
   }
}

unsigned char testModeNumber_L;
unsigned char testModeSelected_L;


void TestMode(void)
{
   while(1)
   {
      /// test mode.
      WriteAllLeds(ON, ON, OFF);   //blue and red
      testModeNumber_L = 1;
      testModeSelected_L = FALSE;
      WaitForButtonUp();
      WriteOneLedOn(NO_LED);
      while(testModeSelected_L == FALSE)
      {
         unsigned short foo;
         WriteOneLedOn(ONELED_GREEN);
         LongDelayIfNoButtonPress(11);
         foo=0;
         while((foo < testModeNumber_L) && (ReadPushButtons() == NOTHING_PUSHED))
         {
            foo++;
            BlinkBlueLedOnceIfButtonNotPressed();
         }
         WriteOneLedOn(ONELED_GREEN);
         LongDelayIfNoButtonPress(60);

         foo=ReadPushButtons();
         if(foo == GREEN_PUSHED)
         {
            testModeNumber_L++;
            if(testModeNumber_L > 6)
            {
               testModeNumber_L = 1;
            }
            WriteOneLedOn(ONELED_GREEN);
            WaitForButtonUp();
         }
         else if(foo == RED_PUSHED)
         {
            //We have selected a test.  Lock it in.
            testModeSelected_L = TRUE;
            WriteAllLeds(OFF, ON, OFF);   //red
            WaitForButtonUp();
         }
      }

      //test has been selected.  testModeNumber_L
      for(unsigned short x=0; x<5; x++)
      {
         WriteOneLedOn(ONELED_RED);
         LongDelayIfNoButtonPress(11);
         WriteOneLedOn(ONELED_GREEN);
         LongDelayIfNoButtonPress(11);
      }
      WriteOneLedOn(NO_LED);

      switch(testModeNumber_L)
      {
         case 1:
            // read the Power Supply Volts
            while(1)
            {
               unsigned short flashLightsThisNumber_l;
               unsigned short counter_l;
               unsigned short bar;
               bar = ADC_ReadUnbufferedAtoDPort(INCH_0, REF2_5V);
               flashLightsThisNumber_l = 1+(bar>>6);
               counter_l=0;
               while((counter_l < flashLightsThisNumber_l) && (ReadPushButtons() == NOTHING_PUSHED))
               {
                  counter_l++;
                  BlinkBlueLedOnceIfButtonNotPressed();
               }
               WriteOneLedOn(ONELED_GREEN);
               LongDelayIfNoButtonPress(60);
            }
            break;

         case 2:
            //Read the Gel Cel volts
            while(1)
            {
               unsigned short bar;
               unsigned short flashLightsThisNumber_l;
               unsigned short counter_l;
               bar = ADC_ReadUnbufferedAtoDPort(INCH_2, REF2_5V);
               flashLightsThisNumber_l = 1+(bar>>6);
               counter_l=0;
               while((counter_l < flashLightsThisNumber_l) && (ReadPushButtons() == NOTHING_PUSHED))
               {
                  counter_l++;
                  BlinkBlueLedOnceIfButtonNotPressed();
               }
               WriteOneLedOn(ONELED_GREEN);
               LongDelayIfNoButtonPress(60);
            }
            break;


         case 3:
            //Toggle the Relay control
            while(1)
            {
               unsigned short bar;
               bar = ReadPushButtons();
               if(bar == GREEN_PUSHED)
               {
                  WriteOneLedOn(ONELED_GREEN);
                  WriteRelayControl(ON);
               }
               if(bar == RED_PUSHED)
               {
                  WriteOneLedOn(ONELED_RED);
                  WriteRelayControl(OFF);
               }
            }
            break;

         case 4:
            //Toggle the Raspberry PI Shutdown
            while(1)
            {
               unsigned short bar;
               bar = ReadPushButtons();
               if(bar == GREEN_PUSHED)
               {
                  WriteOneLedOn(ONELED_GREEN);
                  WritePiShutdown(ON);
               }
               if(bar == RED_PUSHED)
               {
                  WriteOneLedOn(ONELED_RED);
                  WritePiShutdown(OFF);
               }
            }
            break;

         case 5:
            //Light the Blue LED
            while(1)
            {
               unsigned short bar;
               bar = ReadPushButtons();
               if(bar == GREEN_PUSHED)
               {
                  WriteOneLedOn(ONELED_BLUE);
               }
               if(bar == RED_PUSHED)
               {
                  WriteOneLedOn(NO_LED);
               }
            }
            break;

         case 6:
            //Light all three LEDs
            while(1)
            {
               unsigned short bar;
               bar = ReadPushButtons();
               if(bar == GREEN_PUSHED)
               {
                  WriteAllLeds(ON, ON, ON);
               }
               if(bar == RED_PUSHED)
               {
                  WriteOneLedOn(NO_LED);
               }
            }
            break;

         default:
            break;
      }
   }
}
#endif



